# Pyrustic Open Ecosystem
Collection of lightweight `Python` projects that share the same policy.

## Projects

### Frameworks
|Name | Description|
|---|---|
|[TkF](https://github.com/pyrustic/tkf) | `Tkinter`-based framework to build Python apps|
|[Gaspium](https://github.com/pyrustic/gaspium) | High-productivity framework to build `GASP` apps|

### Libraries
|Name | Description|
|---|---|
|[Shared](https://github.com/pyrustic/shared) |  Library to store, expose, read, and edit `collections` of data|
|[TkStyle](https://github.com/pyrustic/tkstyle) | Library to create `styles` and `themes` for Python apps|
|[Litemark](https://github.com/pyrustic/litemark) | Lightweight `Markdown` dialect for Python apps|
|[Megawidget](https://github.com/pyrustic/megawidget) | Collection of `megawidgets` to build graphical user interfaces for Python apps|
|[Viewable](https://github.com/pyrustic/viewable) | Class to implement a GUI view with `lifecycle`|
|[Threadom](https://github.com/pyrustic/threadom) | Tkinter-compatible `multithreading`|
|[Suggestion](https://github.com/pyrustic/suggestion) | Democratizing `auto-complete`(suggest) for Python desktop applications|
|[Kurl](https://github.com/pyrustic/kurl) | Konnection URL: `HTTP requests` in Python with an implementation of `conditional request` and a `responses caching` system|
|[Litedao](https://github.com/pyrustic/litedao) | Library to perform intuitive interaction with `SQLite` database|
|[Probed](https://github.com/pyrustic/probed) | Probed `collections` for Python|


### Themes
|Name | Description|
|---|---|
|[Cyberpunk-Theme](https://github.com/pyrustic/cyberpunk-theme) | A modern `dark theme` for Python apps|
|[Winter-Theme](https://github.com/pyrustic/winter-theme) | A modern `light theme` for Python apps|

### Command line tools
|Name | Description|
|---|---|
|[Backstage](https://github.com/pyrustic/backstage) | `CLI` tool to manage, test, build, and release your Python `projects`|

### Apps
|Name | Description|
|---|---|
|[Codegame](https://github.com/pyrustic/codegame) | Python app to create, distribute, discover, and run `codegames`|
|[Hubstore](https://github.com/pyrustic/hubstore) | Distribute, promote, discover, install, and run Python desktop applications|
|[Jupitest](https://github.com/pyrustic/jupitest) | Graphical test runner built with the framework `TkF`|
|[Rustiql](https://github.com/pyrustic/rustiql) | Graphical SQL editor built with the framework `TkF`|


## Installation
### For the first time
Each package listed above can be installed individually from [PyPI](https://pypi.org). You can still install all the packages with just one single command:

```bash
pip install pyrustic
```

### Upgrade
```bash
$ pip install pyrustic --upgrade --upgrade-strategy eager

```

## Goal
To build and maintain, with the help of tech enthusiasts, a reliable, consistent, easy-to-use and relevant Python codebase for novice and experienced developers.





